Module: Featuring::Delegatable::ClassMethods
- Defined in:
- lib/featuring/delegatable.rb
Instance Method Summary collapse
-
#internal_feature_delegator_class ⇒ Object
Returns the delegator class that responds to all feature check methods and delegates other method calls to its wrapped object.
Instance Method Details
#internal_feature_delegator_class ⇒ Object
Returns the delegator class that responds to all feature check methods and delegates other method calls to its wrapped object.
54 55 56 57 58 |
# File 'lib/featuring/delegatable.rb', line 54 def internal_feature_delegator_class @_internal_feature_delegator_class ||= Class.new(SimpleDelegator).tap { |klass| klass.include internal_feature_module } end |